@@ -5,17 +5,17 @@ try:
 except ImportError:
     raise RuntimeError("Please use pretix 2.7 or above to run this plugin!")
 
-__version__ = '0.2.0'
+__version__ = '0.3.0'
 
 
 class PluginApp(PluginConfig):
     name = 'pretix_bambora_payform'
-    verbose_name = 'Bambora Payform'
+    verbose_name = 'Visma Pay'
 
     class PretixPluginMeta:
-        name = 'Bambora Payform'
+        name = 'Visma Pay'
         author = 'Jaakko Rinta-Filppula'
-        description = gettext_lazy('Payment plugin for Bambora Payform')
+        description = gettext_lazy('Payment plugin for Visma Pay')
         visible = True
         version = __version__
         category = 'PAYMENT'
