@@ -5,23 +5,23 @@ from django.utils.translation import ugettext_lazy as _
 from django.template.loader import render_to_string
 
 from pretix.base.payment import BasePaymentProvider
-from pretix.base.settings import GlobalSettingsObject
 
 from .bambora import BamboraPayformClient
+from .utils import get_credentials
 
 
 class BamboraPayformProvider(BasePaymentProvider):
     def __init__(self, event):
         super().__init__(event)
 
-        gs = GlobalSettingsObject()
+        credentials = get_credentials(event)
         self.client = BamboraPayformClient(
-            gs.settings.get('payment_bambora_payform_api_key'),
-            gs.settings.get('payment_bambora_payform_private_key')
+            credentials.get('api_key'),
+            credentials.get('private_key')
         )
 
     def checkout_confirm_render(self, request):
-        return _('You will be redirected to Bambora Payform to complete the payment')
+        return _('You will be redirected to Visma Pay to complete the payment')
 
     def execute_payment(self, request, payment):
         callback_url = request.build_absolute_uri(
@@ -52,28 +52,16 @@ class BamboraPayformProvider(BasePaymentProvider):
         return True
 
     def payment_form_render(self, request, total):
-        methods = self.client.get_payment_methods()['payment_methods']
-        grouped_methods = {}
-        for method in methods:
-            normalized_name = method['name'].lower().replace(' ', '')
-            method['local_img'] = 'pretix_bambora_payform/payment_methods/{}.png'.format(normalized_name)
-
-            if not method['group'] in grouped_methods.keys():
-                grouped_methods[method['group']] = []
-
-            grouped_methods[method['group']].append(method)
-
-        html = render_to_string(
-            'pretix_bambora_payform/payment_form.html',
-            {'grouped_methods': grouped_methods}
-        )
-
-        return html
+        return render_to_string('pretix_bambora_payform/payment_form.html')
 
     @property
     def public_name(self):
         return '{} – {}'.format(_('Bank and credit card payments'), self.verbose_name)
 
+    @property
+    def test_mode_message(self):
+        return _('Payment will be simulated while the shop is in test mode. No money will be transferred. Read more at: %(url)s') % {'url': 'https://payform.bambora.com/docs/web_payments/?page=testing'}
+
     @property
     def verbose_name(self):
-        return 'Bambora Payform'
+        return 'Visma Pay'
